Skip to contents

Launches the interactive Shiny dashboard for random walk simulations. This is a convenience wrapper that combines the input and output modules into a complete application.

Usage

run_dashboard(...)

Arguments

...

Additional arguments passed to shiny::shinyApp().

Value

A Shiny app object.

Examples

if (FALSE) { # \dontrun{
# Launch the dashboard
run_dashboard()
} # }